==> citrine-0.9.5.tar.gz: citrine-0.9.5/i18n/no/dictionary.h <==
#define CTR_DICT_CODEGEN_MAP_NEW                 "(Liste ny) "
#define CTR_DICT_CODEGEN_MAP_PUT                 "sagt:"
#define CTR_DICT_CODEGEN_MAP_PUT_AT              " at:"
#define CTR_DICT_CODEGEN_ARRAY_NEW               "Rad ny "
#define CTR_DICT_CODEGEN_ARRAY_NEW_PUSH          "Rad ← "
#define CTR_DICT_END_OF_LINE     "."
#define CTR_DICT_NIL              "Tom"
#define CTR_DICT_BOOLEAN          "Boolean"
#define CTR_DICT_TRUE             "Ekte"
#define CTR_DICT_FALSE            "Falsk"
#define CTR_DICT_NUMBER           "Nummer"
#define CTR_DICT_STRING           "Tekst"
#define CTR_DICT_TASK             "Oppgave"
#define CTR_DICT_OBJECT           "Objekt"
#define CTR_DICT_ARRAY_OBJECT      "Rad"
#define CTR_DICT_MAP_OBJECT       "Liste"
#define CTR_DICT_PROGRAM        "Program"
#define CTR_DICT_FILE             "Fil"
#define CTR_DICT_MOMENT       "Øyeblikk"
#define CTR_DICT_VAR_ICON        "☞"
#define CTR_DICT_ME_ICON         "⛏"
#define CTR_DICT_MY_ICON         "⚿"
#define CTR_DICT_BULLET          "•"
#define CTR_DICT_SYMBOL_EQUALS   "="
#define CTR_DICT_PLUS            "+"
#define CTR_DICT_MINUS   	     "-"
#define CTR_DICT_MULTIPLIER   	 "×"
#define CTR_DICT_DIVISION   	 "÷"
#define CTR_DICT_GREATER   	     ">"
#define CTR_DICT_LESS   	     "<"
#define CTR_DICT_AT_SYMBOL       "?" 
#define CTR_DICT_PEN_ICON        "✎"
#define CTR_DICT_NEW_ARRAY_AND_PUSH_SYMBOL       "←"
#define CTR_DICT_GREATER_OR_EQUAL_SYMBOL         "≥"
#define CTR_DICT_LESS_OR_EQUAL_SYMBOL            "≤"
#define CTR_DICT_UNEQUALS_SYMBOL                 "≠"
#define CTR_DICT_NEW              "ny"
#define CTR_DICT_EQUALS           "er lik:"
#define CTR_DICT_AND              "og:"
#define CTR_DICT_OR               "eller:"
#define CTR_DICT_MODULO           "modulo:"
#define CTR_DICT_NOR              "heller ikke:"
#define CTR_DICT_ONDO             "på:gjøre:"
#define CTR_DICT_TYPE             "type"
#define CTR_DICT_ISNIL            "tom?"
#define CTR_DICT_MYSELF           "meg selv"
#define CTR_DICT_DO               "gjøre"
#define CTR_DICT_DONE             "ferdig"
#define CTR_DICT_IFFALSE          "falsk:"
#define CTR_DICT_IFTRUE           "ekte:"
#define CTR_DICT_WHILE            "samtidig som:"
#define CTR_DICT_MESSAGEARGS      "beskjed:argumenter:"
#define CTR_DICT_MESSAGE          "beskjed:"
#define CTR_DICT_LEARN            "lære:hjelp:"
#define CTR_DICT_BREAK            "stoppe"
#define CTR_DICT_CONTINUE         "fortsette"
#define CTR_DICT_ELSE             "ellers:"
#define CTR_DICT_NOT              "ikke"
#define CTR_DICT_TONUMBER         "nummer"
#define CTR_DICT_ITONUMBER        "internasjonalt nummer"
#define CTR_DICT_TOSTRING         "tekst"
#define CTR_DICT_CHAR_AT_SET      "karakter:"
#define CTR_DICT_EITHEROR         "enten:eller:"
#define CTR_DICT_BY_SET       	  "av:"
#define CTR_DICT_FLOOR            "rundet ned"
#define CTR_DICT_CEIL             "rundet opp"
#define CTR_DICT_ROUND            "rundet"
#define CTR_DICT_ABS              "absolutte"
#define CTR_DICT_SQRT             "kvadratrot"
#define CTR_DICT_POWER            "makt:"
#define CTR_DICT_MIN              "minimum"
#define CTR_DICT_MAX              "maksimum"
#define CTR_DICT_ODD   	          "oddetall?"
#define CTR_DICT_EVEN   	      "partall?"
#define CTR_DICT_POS   	          "positiv?"
#define CTR_DICT_NEG   	          "negativ?"
#define CTR_DICT_TOBOOL           "boolean"
#define CTR_DICT_RANDOM_NUM_BETWEEN          "mellom:og:"
#define CTR_DICT_LENGTH	          "lengde"
#define CTR_DICT_FROM_LENGTH	  "fra:lengde:"
#define CTR_DICT_TRIM	          "fjerne omkringliggende områder"
#define CTR_DICT_AT               "på:"
#define CTR_DICT_POSITION_SET     "stilling:"
#define CTR_DICT_INDEX_OF         "finne:"
#define CTR_DICT_LAST_INDEX_OF	  "siste:"
#define CTR_DICT_REPLACE_WITH	  "erstatt:med:"
#define CTR_DICT_SPLIT	          "dele:"
#define CTR_DICT_SKIP             "offset:"
#define CTR_DICT_RUN              "løpe"
#define CTR_DICT_APPLY_TO         "søke om:"
#define CTR_DICT_APPLY_TO_AND     "gjelder:og:"
#define CTR_DICT_VALUE_SET        "satt:verdi:"
#define CTR_DICT_ERROR	          "feil:"
#define CTR_DICT_CATCH            "å fange:"
#define CTR_DICT_PUSH_SYMBOL     ";"
#define CTR_DICT_SHIFT            "ta først"
#define CTR_DICT_COUNT            "telle"
#define CTR_DICT_JOIN             "bli med:"
#define CTR_DICT_POP              "ta sist"
#define CTR_DICT_SORT             "sortere:"
#define CTR_DICT_PUT_AT           "sagt:at:"
#define CTR_DICT_MAP              "liste:"
#define CTR_DICT_EACH             "hver:"
#define CTR_DICT_WRITE            "skrive:"
#define CTR_DICT_PATH             "sti"
#define CTR_DICT_READ             "lese"
#define CTR_DICT_APPEND           "tilføy:"
#define CTR_DICT_PREPEND          "foranstilte:"
#define CTR_DICT_EXISTS           "finnes"
#define CTR_DICT_SIZE             "størrelse"
#define CTR_DICT_DELETE           "slette"
#define CTR_DICT_USE_SET          "bruk:"
#define CTR_DICT_ARRAY             "rad:"
#define CTR_DICT_END              "slutt"
#define CTR_DICT_ARGUMENT	      "argument:"
#define CTR_DICT_ARGUMENT_COUNT	  "argumenter"
#define CTR_DICT_WAIT_FOR_PASSW	  "spør passord"
#define CTR_DICT_WAIT_FOR_INPUT	  "spørre"
#define CTR_DICT_INPUT            "inngang"
#define CTR_DICT_FLUSH            "flush"
#define CTR_DICT_WAIT             "vente:"
#define CTR_DICT_TIME	          "tid"
#define CTR_DICT_RESPOND_TO       "svar:"
#define CTR_DICT_RESPOND_TO_AND   "svare:og:"
#define CTR_DICT_SHELL            "kommandolinje:"
#define CTR_DICT_SWEEP            "ren minne"
#define CTR_DICT_MEMORY_LIMIT	  "minnegrense:"
#define CTR_DICT_MEMORY           "minnegrense"
#define CTR_DICT_GC_MODE             "datamaskinens minne:"
#define CTR_DICT_HASH_WITH_KEY    "hash:"
#define CTR_DICT_CHARACTERS       "tegn"
#define CTR_DICT_QUALIFIER_SET          "kvalifisere:"
#define CTR_DICT_QUALIFIER    "kvalifikasjon"
#define CTR_DICT_NEW_SET          "ny:"
#define CTR_DICT_HOUR             "time"
#define CTR_DICT_HOUR_SET         "time:"
#define CTR_DICT_MINUTE_SET       "minutt:"
#define CTR_DICT_MINUTE           "minutt"
#define CTR_DICT_SECOND_SET       "sekund:"
#define CTR_DICT_SECOND           "sekund"
#define CTR_DICT_DAY              "dag"
#define CTR_DICT_DAY_SET          "dag:"
#define CTR_DICT_WEEK             "uke"
#define CTR_DICT_WEEK_SET         "uke:"
#define CTR_DICT_MONTH            "måned"
#define CTR_DICT_MONTH_SET        "måned:"
#define CTR_DICT_YEAR             "år"
#define CTR_DICT_RAW              "rå"
#define CTR_DICT_YEAR_SET         "år:"
#define CTR_DICT_WEEK_DAY         "ukedag"
#define CTR_DICT_YEAR_DAY         "dag i året"
#define CTR_DICT_ZONE             "sone"
#define CTR_DICT_ZONE_SET         "sone:"
#define CTR_DICT_ADD_SET          "legg til:"
#define CTR_DICT_SUBTRACT_SET     "trekke fra:"
#define CTR_DICT_MULTIPLIER_SET   "multipliser med:"
#define CTR_DICT_DIVIDER_SET      "delt på:"
#define CTR_DICT_LAST             "siste"
#define CTR_DICT_FIRST            "først"
#define CTR_DICT_SECOND_LAST      "nest sist"
#define CTR_DICT_FILL_WITH        "fyll:med:"
#define CTR_DICT_SPLICE           "erstatte:lengde:med:"
#define CTR_DICT_VALUES           "verdier"
#define CTR_DICT_ENTRIES          "innganger"
#define CTR_DICT_COMPARE_SET      "sammenligne:"
#define CTR_DICT_HAS              "har:"
#define CTR_DICT_COPY             "kopiere"
#define CTR_DICT_CASE_DO          "case:gjøre:"
#define CTR_DICT_STOP             "stop"
#define CTR_DICT_ASCII_UPPER_CASE                 "stor bokstav"
#define CTR_DICT_ASCII_LOWER_CASE                 "små bokstaver"
#define CTR_DICT_CONTAINS                         "inneholder:"
#define CTR_DICT_APPLY_TO_AND_AND                 "gjelder:og:og:"
#define CTR_DICT_ENVIRONMENT_VARIABLE             "omgivelser:"
#define CTR_DICT_SET_ENVIRONMENT_VARIABLE         "innstilling:verdi:"
#define CTR_DICT_RESPOND_TO_AND_AND               "svare:og:og:"
#define CTR_DICT_RESPOND_TO_AND_AND_AND           "svare:og:og:og:"
#define CTR_DICT_CURRENT_TASK                       "nåværende oppgave"
#define CTR_DICT_NUM_DEC_SEP                     ","
#define CTR_DICT_NUM_THO_SEP                     "."
#define CTR_DICT_QUOT_OPEN                       "‘"
#define CTR_DICT_QUOT_CLOSE                      "’"
#define CTR_DICT_MESSAGE_CHAIN                   ","
#define CTR_DICT_ASSIGN                          "≔"
#define CTR_DICT_PAREN_OPEN                      "("
#define CTR_DICT_PAREN_CLOSE                     ")"
#define CTR_DICT_BLOCK_START                     "{"
#define CTR_DICT_BLOCK_END                       "}"
#define CTR_DICT_PARAMETER_PREFIX                ":"
#define CTR_DICT_RETURN                          "↲"
#define CTR_DICT_CODE                            "code"
#define CTR_DICT_PROCEDURE                       "fremgangsmåte"
#define CTR_DICT_TOOBJECT        "objekt"
#define CTR_DICT_PATH_OBJECT "Filplassering"
#define CTR_DICT_CMD_OBJECT  "Instruksjon"
#define CTR_DICT_RECURSIVE "tilbakevendende"

==> citrine-0.9.6.tar.gz: citrine-0.9.6/i18n/no/dictionary.h <==
#define CTR_DICT_CODEGEN_MAP_NEW                 "(Liste ny) "
#define CTR_DICT_CODEGEN_MAP_PUT                 "sagt:"
#define CTR_DICT_CODEGEN_MAP_PUT_AT              " at:"
#define CTR_DICT_CODEGEN_ARRAY_NEW               "Rad ny "
#define CTR_DICT_CODEGEN_ARRAY_NEW_PUSH          "Rad ← "
#define CTR_DICT_END_OF_LINE     "."
#define CTR_DICT_NIL              "Tom"
#define CTR_DICT_BOOLEAN          "Boolean"
#define CTR_DICT_TRUE             "Ekte"
#define CTR_DICT_FALSE            "Falsk"
#define CTR_DICT_NUMBER           "Tall"
#define CTR_DICT_STRING           "Tekst"
#define CTR_DICT_TASK             "Oppgave"
#define CTR_DICT_OBJECT           "Objekt"
#define CTR_DICT_ARRAY_OBJECT      "Rad"
#define CTR_DICT_MAP_OBJECT       "Liste"
#define CTR_DICT_PROGRAM        "Program"
#define CTR_DICT_FILE             "Fil"
#define CTR_DICT_MOMENT       "Øyeblikk"
#define CTR_DICT_VAR_ICON        "☞"
#define CTR_DICT_ME_ICON         "⛏"
#define CTR_DICT_MY_ICON         "⚿"
#define CTR_DICT_BULLET          "•"
#define CTR_DICT_SYMBOL_EQUALS   "="
#define CTR_DICT_PLUS            "+"
#define CTR_DICT_MINUS   	     "-"
#define CTR_DICT_MULTIPLIER   	 "×"
#define CTR_DICT_DIVISION   	 "÷"
#define CTR_DICT_GREATER   	     ">"
#define CTR_DICT_LESS   	     "<"
#define CTR_DICT_AT_SYMBOL       "?" 
#define CTR_DICT_PEN_ICON        "✎"
#define CTR_DICT_NEW_ARRAY_AND_PUSH_SYMBOL       "←"
#define CTR_DICT_GREATER_OR_EQUAL_SYMBOL         "≥"
#define CTR_DICT_LESS_OR_EQUAL_SYMBOL            "≤"
#define CTR_DICT_UNEQUALS_SYMBOL                 "≠"
#define CTR_DICT_NEW              "ny"
#define CTR_DICT_EQUALS           "er lik:"
#define CTR_DICT_AND              "og:"
#define CTR_DICT_OR               "eller:"
#define CTR_DICT_MODULO           "modulo:"
#define CTR_DICT_NOR              "heller ikke:"
#define CTR_DICT_ONDO             "på:gjøre:"
#define CTR_DICT_TYPE             "type"
#define CTR_DICT_ISNIL            "tom?"
#define CTR_DICT_MYSELF           "meg selv"
#define CTR_DICT_DO               "gjøre"
#define CTR_DICT_DONE             "ferdig"
#define CTR_DICT_IFFALSE          "falsk:"
#define CTR_DICT_IFTRUE           "ekte:"
#define CTR_DICT_WHILE            "mens:"
#define CTR_DICT_MESSAGEARGS      "beskjed:argumenter:"
#define CTR_DICT_MESSAGE          "beskjed:"
#define CTR_DICT_LEARN            "lære:hjelp:"
#define CTR_DICT_BREAK            "stoppe"
#define CTR_DICT_CONTINUE         "fortsette"
#define CTR_DICT_ELSE             "ellers:"
#define CTR_DICT_NOT              "ikke"
#define CTR_DICT_TONUMBER         "tall"
#define CTR_DICT_ITONUMBER        "internasjonalt tall"
#define CTR_DICT_TOSTRING         "tekst"
#define CTR_DICT_CHAR_AT_SET      "karakter:"
#define CTR_DICT_EITHEROR         "enten:eller:"
#define CTR_DICT_BY_SET       	  "av:"
#define CTR_DICT_FLOOR            "rundet ned"
#define CTR_DICT_CEIL             "rundet opp"
#define CTR_DICT_ROUND            "rundet"
#define CTR_DICT_ABS              "absolutte"
#define CTR_DICT_SQRT             "kvadratrot"
#define CTR_DICT_POWER            "makt:"
#define CTR_DICT_MIN              "minimum"
#define CTR_DICT_MAX              "maksimum"
#define CTR_DICT_ODD   	          "oddetall?"
#define CTR_DICT_EVEN   	      "partall?"
#define CTR_DICT_POS   	          "positiv?"
#define CTR_DICT_NEG   	          "negativ?"
#define CTR_DICT_TOBOOL           "boolean"
#define CTR_DICT_RANDOM_NUM_BETWEEN          "mellom:og:"
#define CTR_DICT_LENGTH	          "lengde"
#define CTR_DICT_FROM_LENGTH	  "fra:lengde:"
#define CTR_DICT_TRIM	          "fjerne omkringliggende områder"
#define CTR_DICT_AT               "på:"
#define CTR_DICT_POSITION_SET     "stilling:"
#define CTR_DICT_INDEX_OF         "finne:"
#define CTR_DICT_LAST_INDEX_OF	  "siste:"
#define CTR_DICT_REPLACE_WITH	  "erstatt:med:"
#define CTR_DICT_SPLIT	          "dele:"
#define CTR_DICT_SKIP             "offset:"
#define CTR_DICT_RUN              "start"
#define CTR_DICT_APPLY_TO         "søke om:"
#define CTR_DICT_APPLY_TO_AND     "gjelder:og:"
#define CTR_DICT_VALUE_SET        "satt:verdi:"
#define CTR_DICT_ERROR	          "feil:"
#define CTR_DICT_CATCH            "å fange:"
#define CTR_DICT_PUSH_SYMBOL     ";"
#define CTR_DICT_SHIFT            "ta først"
#define CTR_DICT_COUNT            "telle"
#define CTR_DICT_JOIN             "bli med:"
#define CTR_DICT_POP              "ta sist"
#define CTR_DICT_SORT             "sortere:"
#define CTR_DICT_PUT_AT           "sagt:at:"
#define CTR_DICT_MAP              "liste:"
#define CTR_DICT_EACH             "hver:"
#define CTR_DICT_WRITE            "skrive:"
#define CTR_DICT_PATH             "sti"
#define CTR_DICT_READ             "lese"
#define CTR_DICT_APPEND           "tilføy:"
#define CTR_DICT_PREPEND          "foranstilte:"
#define CTR_DICT_EXISTS           "finnes"
#define CTR_DICT_SIZE             "størrelse"
#define CTR_DICT_DELETE           "slette"
#define CTR_DICT_USE_SET          "bruk:"
#define CTR_DICT_ARRAY             "rad:"
#define CTR_DICT_END              "slutt"
#define CTR_DICT_ARGUMENT	      "argument:"
#define CTR_DICT_ARGUMENT_COUNT	  "argumenter"
#define CTR_DICT_WAIT_FOR_PASSW	  "spør passord"
#define CTR_DICT_WAIT_FOR_INPUT	  "spørre"
#define CTR_DICT_INPUT            "inngang"
#define CTR_DICT_FLUSH            "flush"
#define CTR_DICT_WAIT             "vente:"
#define CTR_DICT_TIME	          "tid"
#define CTR_DICT_RESPOND_TO       "svar:"
#define CTR_DICT_RESPOND_TO_AND   "svare:og:"
#define CTR_DICT_SHELL            "kommandolinje:"
#define CTR_DICT_SWEEP            "ren minne"
#define CTR_DICT_MEMORY_LIMIT	  "minnegrense:"
#define CTR_DICT_MEMORY           "minnegrense"
#define CTR_DICT_GC_MODE             "datamaskinens minne:"
#define CTR_DICT_HASH_WITH_KEY    "hash:"
#define CTR_DICT_CHARACTERS       "tegn"
#define CTR_DICT_QUALIFIER_SET          "kvalifisere:"
#define CTR_DICT_QUALIFIER    "kvalifikasjon"
#define CTR_DICT_NEW_SET          "ny:"
#define CTR_DICT_HOUR             "time"
#define CTR_DICT_HOUR_SET         "time:"
#define CTR_DICT_MINUTE_SET       "minutt:"
#define CTR_DICT_MINUTE           "minutt"
#define CTR_DICT_SECOND_SET       "sekund:"
#define CTR_DICT_SECOND           "sekund"
#define CTR_DICT_DAY              "dag"
#define CTR_DICT_DAY_SET          "dag:"
#define CTR_DICT_WEEK             "uke"
#define CTR_DICT_WEEK_SET         "uke:"
#define CTR_DICT_MONTH            "måned"
#define CTR_DICT_MONTH_SET        "måned:"
#define CTR_DICT_YEAR             "år"
#define CTR_DICT_RAW              "rå"
#define CTR_DICT_YEAR_SET         "år:"
#define CTR_DICT_WEEK_DAY         "ukedag"
#define CTR_DICT_YEAR_DAY         "dag i året"
#define CTR_DICT_ZONE             "sone"
#define CTR_DICT_ZONE_SET         "sone:"
#define CTR_DICT_ADD_SET          "legg til:"
#define CTR_DICT_SUBTRACT_SET     "trekke fra:"
#define CTR_DICT_MULTIPLIER_SET   "multipliser med:"
#define CTR_DICT_DIVIDER_SET      "delt på:"
#define CTR_DICT_LAST             "siste"
#define CTR_DICT_FIRST            "først"
#define CTR_DICT_SECOND_LAST      "nest sist"
#define CTR_DICT_FILL_WITH        "fyll:med:"
#define CTR_DICT_SPLICE           "erstatte:lengde:med:"
#define CTR_DICT_VALUES           "verdier"
#define CTR_DICT_ENTRIES          "innganger"
#define CTR_DICT_COMPARE_SET      "sammenligne:"
#define CTR_DICT_HAS              "har:"
#define CTR_DICT_COPY             "kopiere"
#define CTR_DICT_CASE_DO          "case:gjøre:"
#define CTR_DICT_STOP             "stop"
#define CTR_DICT_ASCII_UPPER_CASE                 "stor bokstav"
#define CTR_DICT_ASCII_LOWER_CASE                 "små bokstaver"
#define CTR_DICT_CONTAINS                         "inneholder:"
#define CTR_DICT_APPLY_TO_AND_AND                 "gjelder:og:og:"
#define CTR_DICT_ENVIRONMENT_VARIABLE             "omgivelser:"
#define CTR_DICT_SET_ENVIRONMENT_VARIABLE         "innstilling:verdi:"
#define CTR_DICT_RESPOND_TO_AND_AND               "svare:og:og:"
#define CTR_DICT_RESPOND_TO_AND_AND_AND           "svare:og:og:og:"
#define CTR_DICT_CURRENT_TASK                       "nåværende oppgave"
#define CTR_DICT_NUM_DEC_SEP                     ","
#define CTR_DICT_NUM_THO_SEP                     "."
#define CTR_DICT_QUOT_OPEN                       "‘"
#define CTR_DICT_QUOT_CLOSE                      "’"
#define CTR_DICT_MESSAGE_CHAIN                   ","
#define CTR_DICT_ASSIGN                          "≔"
#define CTR_DICT_PAREN_OPEN                      "("
#define CTR_DICT_PAREN_CLOSE                     ")"
#define CTR_DICT_BLOCK_START                     "{"
#define CTR_DICT_BLOCK_END                       "}"
#define CTR_DICT_PARAMETER_PREFIX                ":"
#define CTR_DICT_RETURN                          "↲"
#define CTR_DICT_CODE                            "code"
#define CTR_DICT_PROCEDURE                       "fremgangsmåte"
#define CTR_DICT_TOOBJECT        "objekt"
#define CTR_DICT_PATH_OBJECT "Filplassering"
#define CTR_DICT_CMD_OBJECT  "Instruksjon"
#define CTR_DICT_RECURSIVE "tilbakevendende"
